@@ -22,7 +22,7 @@ def tensorleap_custom_metric(name: str, direction: Optional[MetricDirection] = M
             ConfusionMatrixCallableInterfaceMultiArgs]
     ):
         for metric_handler in leap_binder.setup_container.metrics:
-            if metric_handler.name == name:
+            if metric_handler.metric_handler_data.name == name:
                 raise Exception(f'Metric with name {name} already exists. '
                                 f'Please choose another')
 
@@ -94,7 +94,7 @@ def tensorleap_custom_visualizer(name: str, visualizer_type: LeapDataType,
                                  heatmap_function: Optional[Callable[..., npt.NDArray[np.float32]]] = None):
     def decorating_function(user_function: VisualizerCallableInterface):
         for viz_handler in leap_binder.setup_container.visualizers:
-            if viz_handler.name == name:
+            if viz_handler.visualizer_handler_data.name == name:
                 raise Exception(f'Visualizer with name {name} already exists. '
                                 f'Please choose another')
 
@@ -334,44 +334,42 @@ def tensorleap_gt_encoder(name: str):
 def tensorleap_custom_loss(name: str):
     def decorating_function(user_function: CustomCallableInterface):
         for loss_handler in leap_binder.setup_container.custom_loss_handlers:
-            if loss_handler.name == name:
+            if loss_handler.custom_loss_handler_data.name == name:
                 raise Exception(f'Custom loss with name {name} already exists. '
                                 f'Please choose another')
 
         leap_binder.add_custom_loss(user_function, name)
 
+        valid_types = np.ndarray
+        try:
+            import tensorflow as tf
+            valid_types = (np.ndarray, tf.Tensor)
+        except ImportError:
+            pass
+
         def _validate_input_args(*args, **kwargs):
-            try:
-                import tensorflow as tf
-            except ImportError as e:
-                raise Exception('the input arguments of the custom loss function should be tensorflow tensors') from e
 
             for i, arg in enumerate(args):
                 if isinstance(arg, list):
                     for y, elem in enumerate(arg):
-                        assert isinstance(elem, tf.Tensor), (f'tensorleap_custom_loss validation failed: '
-                                                             f'Element #{y} of list should be a tensorflow tensor. Got {type(elem)}.')
+                        assert isinstance(elem, valid_types), (f'tensorleap_custom_loss validation failed: '
+                                                               f'Element #{y} of list should be a numpy array. Got {type(elem)}.')
                 else:
                     assert isinstance(arg, tf.Tensor), (f'tensorleap_custom_loss validation failed: '
-                                                        f'Argument #{i} should be a tensorflow tensor. Got {type(arg)}.')
+                                                        f'Argument #{i} should be a numpy array. Got {type(arg)}.')
             for _arg_name, arg in kwargs.items():
                 if isinstance(arg, list):
                     for y, elem in enumerate(arg):
-                        assert isinstance(elem, tf.Tensor), (f'tensorleap_custom_loss validation failed: '
-                                                             f'Element #{y} of list should be a tensorflow tensor. Got {type(elem)}.')
+                        assert isinstance(elem,valid_types), (f'tensorleap_custom_loss validation failed: '
+                                                             f'Element #{y} of list should be a numpy array. Got {type(elem)}.')
                 else:
-                    assert isinstance(arg, tf.Tensor), (f'tensorleap_custom_loss validation failed: '
-                                                        f'Argument #{_arg_name} should be a tensorflow tensor. Got {type(arg)}.')
+                    assert isinstance(arg, valid_types), (f'tensorleap_custom_loss validation failed: '
+                                                        f'Argument #{_arg_name} should be a numpy array. Got {type(arg)}.')
 
         def _validate_result(result):
-            try:
-                import tensorflow as tf
-            except ImportError:
-                raise Exception('the input arguments of the custom loss function should be tensorflow tensors')
-
-            assert isinstance(result, (np.ndarray, tf.Tensor)), \
+            assert isinstance(result, valid_types), \
                 (f'tensorleap_custom_loss validation failed: '
-                 f'The return type should be a numpy array or a tensorflow tensor. Got {type(result)}.')
+                 f'The return type should be a numpy array. Got {type(result)}.')
 
         def inner(*args, **kwargs):
             _validate_input_args(*args, **kwargs)
